@@ -1,5 +1,5 @@
 package Date::Manip::Recur;
-# Copyright (c) 1998-2021 Sullivan Beck. All rights reserved.
+# Copyright (c) 1998-2025 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 
@@ -26,7 +26,7 @@ use Date::Manip::Base;
 use Date::Manip::TZ;
 
 our $VERSION;
-$VERSION='6.85';
+$VERSION='6.98';
 END { undef $VERSION; }
 
 ########################################################################
@@ -916,7 +916,7 @@ sub next {
              defined $$self{'data'}{'end'}) {
 
             my $n = $self->_locate_n('first');
-            return (undef,'Not found')  if ($$self{'err'});
+            return (undef,'Not found')  if ($$self{'err'}  ||  ! defined($n));
             $$self{'data'}{'curr'} = $n-1;
 
          } else {
@@ -969,7 +969,7 @@ sub prev {
              defined $$self{'data'}{'end'}) {
 
             my $n = $self->_locate_n('last');
-            return (undef,'Not found')  if ($$self{'err'});
+            return (undef,'Not found')  if ($$self{'err'}  ||  ! defined($n));
             $$self{'data'}{'curr'} = $n+1;
 
          } else {
